
# Type: named thing




URI: [https://example.com/test62/NamedThing](https://example.com/test62/NamedThing)


![img](http://yuml.me/diagram/nofunky;dir:TB/class/)

## Referenced by class


## Attributes


### Own

 * [category](category.md)  <sub>1..*</sub>
    * range: [IriType](types/IriType.md)

### Domain for slot:

 * [category](category.md)  <sub>1..*</sub>
    * range: [IriType](types/IriType.md)
